.. General

======================================================================
Input data for swolfpy's life-cycle process models (swolfpy_inputdata)
======================================================================

.. image:: https://img.shields.io/pypi/v/swolfpy_inputdata.svg
        :target: https://pypi.python.org/pypi/swolfpy_inputdata
        
.. image:: https://img.shields.io/pypi/pyversions/swolfpy_inputdata.svg
    :target: https://pypi.org/project/swolfpy_inputdata/
    :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/swolfpy_inputdata.svg
    :target: https://pypi.org/project/swolfpy_inputdata/
    :alt: License

.. image:: https://img.shields.io/pypi/format/swolfpy_inputdata.svg
    :target: https://pypi.org/project/swolfpy_inputdata/
    :alt: Format

.. image:: https://readthedocs.org/projects/swolfpy/badge/?version=latest
        :target: https://swolfpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


* Free software: GNU GENERAL PUBLIC LICENSE V2
* Documentation: https://swolfpy.readthedocs.io.
* Repository: https://bitbucket.org/swolfpy/swolfpy-inputdata
* Other links: 
        https://go.ncsu.edu/swolfpy

        https://jwlevis.wixsite.com/swolf


Features
--------
* Input data for Life-cycle process models of swolfpy, include: Landfill, Waste-to-Energy (WTE), Composting, Anaerobic Digestion (AD), Single Stream Material Recovery Facility (MRF), Reprocessing, and Collection.
* Monte Carlo simulation


.. Installation

Installation
------------
1- Download and install miniconda from:  https://docs.conda.io/en/latest/miniconda.html

2- Update conda in a terminal window or anaconda prompt::

        conda update conda

3- Create a new environment for swolfpy::

        conda create --name swolfpy python=3.7

4- Activate the environment::

        conda activate swolfpy

5- Install swolfpy_inputdata in the environment::

        pip install swolfpy_inputdata


.. endInstallation
